@@ -4,7 +4,7 @@
 __version__ = "$Revision: 1.33 $"
 __author__ = "Karsten Hilbert <Karsten.Hilbert@gmx.net>"
 
-import logging, sys, os.path
+import logging, sys, os.path, webbrowser
 
 
 import wx, wx.grid
@@ -22,7 +22,11 @@ from Gnumed.wxpython import gmAllergyWidgets
 
 _log = logging.getLogger('gm.ui')
 _log.info(__version__)
+
 #============================================================
+# ATC related widgets
+#============================================================
+
 def browse_atc_reference(parent=None):
 
 	if parent is None:
@@ -54,6 +58,105 @@ def browse_atc_reference(parent=None):
 	)
 
 #============================================================
+
+def update_atc_reference_data():
+
+	dlg = wx.FileDialog (
+		parent = None,
+		message = _('Choose an ATC import config file'),
+		defaultDir = os.path.expanduser(os.path.join('~', 'gnumed')),
+		defaultFile = '',
+		wildcard = "%s (*.conf)|*.conf|%s (*)|*" % (_('config files'), _('all files')),
+		style = wx.OPEN | wx.HIDE_READONLY | wx.FILE_MUST_EXIST
+	)
+
+	result = dlg.ShowModal()
+	if result == wx.ID_CANCEL:
+		return
+
+	cfg_file = dlg.GetPath()
+	dlg.Destroy()
+
+	conn = gmAuthWidgets.get_dbowner_connection(procedure = _('importing ATC reference data'))
+	if conn is None:
+		return False
+
+	wx.BeginBusyCursor()
+
+	if gmATC.atc_import(cfg_fname = cfg_file, conn = conn):
+		gmDispatcher.send(signal = 'statustext', msg = _('Successfully imported ATC reference data.'))
+	else:
+		gmDispatcher.send(signal = 'statustext', msg = _('Importing ATC reference data failed.'), beep = True)
+
+	wx.EndBusyCursor()
+	return True
+
+#============================================================
+
+class cATCPhraseWheel(gmPhraseWheel.cPhraseWheel):
+
+	def __init__(self, *args, **kwargs):
+
+		gmPhraseWheel.cPhraseWheel.__init__(self, *args, **kwargs)
+
+		query = u"""
+
+			SELECT DISTINCT ON (label)
+				atc_code,
+				label
+			FROM (
+
+				SELECT
+					code as atc_code,
+					(code || ': ' || term || coalesce(' (' || ddd || unit || ')', ''))
+						AS label
+				FROM ref.atc
+				WHERE
+					term %(fragment_condition)s
+						OR
+					code %(fragment_condition)s
+
+				UNION ALL
+
+				SELECT
+					atc_code,
+					(atc_code || ': ' || description)
+						AS label
+				FROM ref.substance_in_brand
+				WHERE
+					description %(fragment_condition)s
+						OR
+					atc_code %(fragment_condition)s
+
+				UNION ALL
+
+				SELECT
+					atc_code,
+					(atc_code || ': ' || description || ' (' || preparation || ')')
+						AS label
+				FROM ref.branded_drug
+				WHERE
+					description %(fragment_condition)s
+						OR
+					atc_code %(fragment_condition)s
+
+				-- it would be nice to be able to include clin.vacc_indication but that's hard to do in SQL
+
+			) AS candidates
+
+			ORDER BY label
+			LIMIT 50"""
+
+		mp = gmMatchProvider.cMatchProvider_SQL2(queries = query)
+		mp.setThresholds(1, 2, 4)
+#		mp.word_separators = '[ \t=+&:@]+'
+		self.SetToolTipString(_('Select an ATC (Anatomical-Therapeutic-Chemical) code.'))
+		self.matcher = mp
+		self.selection_only = True
+
+#============================================================
+#============================================================
+
 def manage_substances_in_brands(parent=None):
 
 	if parent is None:
@@ -74,8 +177,7 @@ def manage_substances_in_brands(parent=None):
 			s['substance'],
 			gmTools.coalesce(s['atc_substance'], u''),
 			s['preparation'],
-			#gmTools.coalesce(s['external_code_brand'], u'', u'%%s [%s]' % s['external_code_type_brand']),
-			gmTools.coalesce(s['external_code_brand'], u''),
+			gmTools.coalesce(s['external_code_brand'], u'', u'%%s [%s]' % s['external_code_type_brand']),
 			s['pk_substance_in_brand']
 		] for s in substs ]
 		lctrl.set_string_items(items)
@@ -101,6 +203,19 @@ def manage_branded_drugs(parent=None):
 		parent = wx.GetApp().GetTopWindow()
 	#------------------------------------------------------------
 	def delete(brand):
+		if brand.is_vaccine:
+			gmGuiHelpers.gm_show_info (
+				aTitle = _('Deleting medication'),
+				aMessage = _(
+					'Cannot delete the medication\n'
+					'\n'
+					' "%s" (%s)\n'
+					'\n'
+					'because it is a vaccine. Please delete it\n'
+					'from the vaccine management section !\n'
+				) % (brand['description'], brand['preparation'])
+			)
+			return False
 		gmMedication.delete_branded_drug(brand = brand['pk'])
 		return True
 	#------------------------------------------------------------
@@ -232,6 +347,7 @@ def get_drug_database(parent = None):
 	except KeyError:
 		_log.error('faulty default drug data source configuration: %s', default_db)
 		return None
+
 #============================================================
 def jump_to_drug_database():
 	dbcfg = gmCfg.cCfgSQL()
@@ -242,6 +358,7 @@ def jump_to_drug_database():
 	if pat.connected:
 		drug_db.patient = pat
 	drug_db.switch_to_frontend(blocking = False)
+
 #============================================================
 def jump_to_ifap(import_drugs=False):
 
@@ -313,38 +430,6 @@ def jump_to_ifap(import_drugs=False):
 			csv_file.close()
 
 	return True
-#============================================================
-def update_atc_reference_data():
-
-	dlg = wx.FileDialog (
-		parent = None,
-		message = _('Choose an ATC import config file'),
-		defaultDir = os.path.expanduser(os.path.join('~', 'gnumed')),
-		defaultFile = '',
-		wildcard = "%s (*.conf)|*.conf|%s (*)|*" % (_('config files'), _('all files')),
-		style = wx.OPEN | wx.HIDE_READONLY | wx.FILE_MUST_EXIST
-	)
-
-	result = dlg.ShowModal()
-	if result == wx.ID_CANCEL:
-		return
-
-	cfg_file = dlg.GetPath()
-	dlg.Destroy()
-
-	conn = gmAuthWidgets.get_dbowner_connection(procedure = _('importing ATC reference data'))
-	if conn is None:
-		return False
-
-	wx.BeginBusyCursor()
-
-	if gmATC.atc_import(cfg_fname = cfg_file, conn = conn):
-		gmDispatcher.send(signal = 'statustext', msg = _('Successfully imported ATC reference data.'))
-	else:
-		gmDispatcher.send(signal = 'statustext', msg = _('Importing ATC reference data failed.'), beep = True)
-
-	wx.EndBusyCursor()
-	return True
 
 #============================================================
 # current substance intake handling
@@ -428,7 +513,10 @@ class cBrandedDrugPhraseWheel(gmPhraseWheel.cPhraseWheel):
 	def __init__(self, *args, **kwargs):
 
 		query = u"""
-			SELECT pk, (coalesce(atc_code || ': ', '') || description || ' (' || preparation || ')') as brand
+			SELECT
+				pk,
+				(description || ' (' || preparation || ')' || coalesce(' [' || atc_code || ']', ''))
+					AS brand
 			FROM ref.branded_drug
 			WHERE description %(fragment_condition)s
 			ORDER BY brand
@@ -720,7 +808,7 @@ class cCurrentMedicationEAPnl(wxgCurrentMedicationEAPnl.wxgCurrentMedicationEAPn
 		self._PRW_duration.SetText(u'', None)
 		self._PRW_aim.SetText(u'', None)
 		self._PRW_notes.SetText(u'', None)
-		self._PRW_episode.SetData(None)
+		self._PRW_episode.SetText(u'', None)
 
 		self._CHBOX_long_term.SetValue(False)
 		self._CHBOX_approved.SetValue(True)
@@ -770,15 +858,6 @@ class cCurrentMedicationEAPnl(wxgCurrentMedicationEAPnl.wxgCurrentMedicationEAPn
 	#----------------------------------------------------------------
 	def _refresh_as_new_from_existing(self):
 		self._refresh_as_new()
-
-		self._PRW_substance.SetText(u'', None)
-		self._PRW_strength.SetText(u'', None)
-		self._PRW_notes.SetText(u'', None)
-
-		self.__refresh_brand_and_components()
-		self.__refresh_allergies()
-
-		self._PRW_substance.SetFocus()
 	#----------------------------------------------------------------
 	# event handlers
 	#----------------------------------------------------------------
@@ -917,7 +996,10 @@ def configure_medication_list_template(parent=None):
 	if parent is None:
 		parent = wx.GetApp().GetTopWindow()
 
-	template = gmFormWidgets.manage_form_templates(parent = parent)
+	template = gmFormWidgets.manage_form_templates (
+		parent = parent,
+		template_types = ['current medication list']
+	)
 	option = u'form_templates.medication_list'
 
 	if template is None:
@@ -1157,9 +1239,10 @@ class cCurrentSubstancesGrid(wx.grid.Grid):
 				atcs = []
 				if med['atc_substance'] is not None:
 					atcs.append(med['atc_substance'])
-				if med['atc_brand'] is not None:
-					atcs.append(med['atc_brand'])
-				allg = emr.is_allergic_to(atcs = tuple(atcs), inns = (med['substance'],), brand = med['brand'])
+#				if med['atc_brand'] is not None:
+#					atcs.append(med['atc_brand'])
+#				allg = emr.is_allergic_to(atcs = tuple(atcs), inns = (med['substance'],), brand = med['brand'])
+				allg = emr.is_allergic_to(atcs = tuple(atcs), inns = (med['substance'],))
 				if allg not in [None, False]:
 					attr = self.GetOrCreateCellAttr(row_idx, 0)
 					if allg['type'] == u'allergy':
@@ -1275,6 +1358,35 @@ class cCurrentSubstancesGrid(wx.grid.Grid):
 
 		drug_db.show_info_on_substance(substance = self.get_selected_data()[0])
 	#------------------------------------------------------------
+	def show_renal_insufficiency_info(self):
+
+		if len(self.__row_data) == 0:
+			return
+
+		sel_rows = self.get_selected_rows()
+
+		if len(sel_rows) != 1:
+			return
+
+		webbrowser.open (
+			url = gmMedication.drug2renal_insufficiency_url(search_term = self.get_selected_data()[0]),
+			new = False,
+			autoraise = True
+		)
+	#------------------------------------------------------------
+	def report_ADR(self):
+
+		dbcfg = gmCfg.cCfgSQL()
+
+		url = dbcfg.get2 (
+			option = u'external.urls.report_ADR',
+			workplace = gmSurgery.gmCurrentPractice().active_workplace,
+			bias = u'user',
+			default = u'https://dcgma.org/uaw/meldung.php'
+		)
+
+		webbrowser.open(url = url, new = False, autoraise = True)
+	#------------------------------------------------------------
 	def check_interactions(self):
 
 		if len(self.__row_data) == 0:
@@ -1358,9 +1470,10 @@ class cCurrentSubstancesGrid(wx.grid.Grid):
 		atcs = []
 		if entry['atc_substance'] is not None:
 			atcs.append(entry['atc_substance'])
-		if entry['atc_brand'] is not None:
-			atcs.append(entry['atc_brand'])
-		allg = emr.is_allergic_to(atcs = tuple(atcs), inns = (entry['substance'],), brand = entry['brand'])
+#		if entry['atc_brand'] is not None:
+#			atcs.append(entry['atc_brand'])
+#		allg = emr.is_allergic_to(atcs = tuple(atcs), inns = (entry['substance'],), brand = entry['brand'])
+		allg = emr.is_allergic_to(atcs = tuple(atcs), inns = (entry['substance'],))
 
 		tt = _('Substance intake entry (%s, %s)   [#%s]                     \n') % (
 			gmTools.bool2subst (
@@ -1624,6 +1737,12 @@ class cCurrentSubstancesPnl(wxgCurrentSubstancesPnl.wxgCurrentSubstancesPnl, gmR
 	#--------------------------------------------------------
 	def _on_allergy_button_pressed(self, event):
 		self._grid_substances.create_allergy_from_substance()
+	#--------------------------------------------------------
+	def _on_button_kidneys_pressed(self, event):
+		self._grid_substances.show_renal_insufficiency_info()
+	#--------------------------------------------------------
+	def _on_adr_button_pressed(self, event):
+		self._grid_substances.report_ADR()
 #============================================================
 # main
 #------------------------------------------------------------
@@ -1641,7 +1760,8 @@ if __name__ == '__main__':
 	gmI18N.install_domain(domain = 'gnumed')
 
 	#----------------------------------------
-#	test_*()
-	pass
+	app = wx.PyWidgetTester(size = (600, 600))
+	app.SetWidget(cATCPhraseWheel, -1)
+	app.MainLoop()
 
 #============================================================
